==> ntex-mqtt-0.7.0.crate: ntex-mqtt-0.7.0/src/v3/client/control.rs <==
pub use crate::v3::control::{Closed, ControlResult, Disconnect, Error, ProtocolError};
use crate::v3::{codec, control::ControlResultKind, error};

pub enum ControlMessage<E> {
    /// Unhandled publish packet
    Publish(Publish),
    /// Disconnect packet
    Disconnect(Disconnect),
    /// Connection closed
    Closed(Closed),
    /// Application level error from resources and control services
    Error(Error<E>),
    /// Protocol level error
    ProtocolError(ProtocolError),
}

impl<E> ControlMessage<E> {
    pub(super) fn publish(pkt: codec::Publish) -> Self {
        ControlMessage::Publish(Publish(pkt))
    }

    pub(super) fn dis() -> Self {
        ControlMessage::Disconnect(Disconnect)
    }

    pub(super) fn closed(is_error: bool) -> Self {
        ControlMessage::Closed(Closed::new(is_error))
    }

    pub(super) fn error(err: E) -> Self {
        ControlMessage::Error(Error::new(err))
    }

    pub(super) fn proto_error(err: error::ProtocolError) -> Self {
        ControlMessage::ProtocolError(ProtocolError::new(err))
    }

    pub fn disconnect(&self) -> ControlResult {
        ControlResult { result: ControlResultKind::Disconnect }
    }
}

pub struct Publish(codec::Publish);

impl Publish {
    /// Returns reference to publish packet
    pub fn packet(&self) -> &codec::Publish {
        &self.0
    }

    /// Returns reference to publish packet
    pub fn packet_mut(&mut self) -> &mut codec::Publish {
        &mut self.0
    }

    pub fn ack(self) -> ControlResult {
        if let Some(id) = self.0.packet_id {
            ControlResult { result: ControlResultKind::PublishAck(id) }
        } else {
            ControlResult { result: ControlResultKind::Nothing }
        }
    }
}

==> ntex-mqtt-0.8.0-b.0.crate: ntex-mqtt-0.8.0-b.0/src/v3/client/control.rs <==
pub use crate::v3::control::{
    Closed, ControlResult, Disconnect, Error, PeerGone, ProtocolError,
};
use crate::v3::{codec, control::ControlResultKind, error};

pub enum ControlMessage<E> {
    /// Unhandled publish packet
    Publish(Publish),
    /// Disconnect packet
    Disconnect(Disconnect),
    /// Connection closed
    Closed(Closed),
    /// Application level error from resources and control services
    Error(Error<E>),
    /// Protocol level error
    ProtocolError(ProtocolError),
    /// Peer is gone
    PeerGone(PeerGone),
}

impl<E> ControlMessage<E> {
    pub(super) fn publish(pkt: codec::Publish) -> Self {
        ControlMessage::Publish(Publish(pkt))
    }

    pub(super) fn dis() -> Self {
        ControlMessage::Disconnect(Disconnect)
    }

    pub(super) fn closed(is_error: bool) -> Self {
        ControlMessage::Closed(Closed::new(is_error))
    }

    pub(super) fn error(err: E) -> Self {
        ControlMessage::Error(Error::new(err))
    }

    pub(super) fn proto_error(err: error::ProtocolError) -> Self {
        ControlMessage::ProtocolError(ProtocolError::new(err))
    }

    pub(super) fn peer_gone() -> Self {
        ControlMessage::PeerGone(PeerGone)
    }

    pub fn disconnect(&self) -> ControlResult {
        ControlResult { result: ControlResultKind::Disconnect }
    }
}

pub struct Publish(codec::Publish);

impl Publish {
    /// Returns reference to publish packet
    pub fn packet(&self) -> &codec::Publish {
        &self.0
    }

    /// Returns reference to publish packet
    pub fn packet_mut(&mut self) -> &mut codec::Publish {
        &mut self.0
    }

    pub fn ack(self) -> ControlResult {
        if let Some(id) = self.0.packet_id {
            ControlResult { result: ControlResultKind::PublishAck(id) }
        } else {
            ControlResult { result: ControlResultKind::Nothing }
        }
    }
}
